

make.multree <- function(network.cfg) {
  multree <- as.list(NULL)
  mnodes <- network.cfg$mulnodes
  multree <- mnodes2mulsubtree(multree, mnodes, length(mnodes))
  # TODO should do some checks: pops equal when they should be?
  multree
  }                        
  


  
print.multree <- function(multree) {
  cladelen <- 30
  alrlen <- cladelen + 9
  dbllen <- 8
  hlen <- alrlen + 2*(dbllen+1)
  
  header.txt <- paste(rgt.pad("idx   clade", cladelen), "anc  l  r", sep="")
  header.txt <- rgt.pad(header.txt, alrlen)
  header.txt <- paste(header.txt, "     hgt   hybhgt")
  header.txt <- rgt.pad(header.txt, hlen)
  header.txt <- paste(header.txt, "nlin")
  header.txt <- paste(header.txt, "  tippop   hybpop  prevpop")
  cat(header.txt, "\n")
  txt.lens <- list(clade=cladelen, alr=alrlen, hgts=hlen, dbl=dbllen)
  for (i in 1:length(multree)) {
    print.multree.node(i, multree[[i]], txt.lens)
    }
  }  
  



print.multree.node <- function(i, mn, txt.lens) {
  cladelen <- txt.lens$clade      
  alrlen <- txt.lens$alr
  hlen <- txt.lens$hgts
  dbllen <- txt.lens$dbl
  txt <- paste(lft.pad(i,2), mn$clade)
  txt <- rgt.pad(txt, cladelen)
  txt <- paste(txt, lft.pad(mn$anc,2), 
                  lft.pad(mn$lft,2), lft.pad(mn$rgt,2))
  txt <- rgt.pad(txt, alrlen)
  txt <- paste(txt, lft.pad(mn$nheight, dbllen),  lft.pad(mn$hybheight, dbllen))
  txt <- rgt.pad(txt, hlen)
  txt <- paste(txt, lft.pad(mn$nlins,4))
  txt <- paste(txt, lft.pad(mn$tippop, dbllen), lft.pad(mn$hybpop, dbllen), 
                   lft.pad(mn$rootpop, dbllen))
  cat(txt, "\n")
  }


lft.pad <- function(txt, n) {
  while (nchar(txt) < n) {
    txt <- paste("", txt)
    }
  txt
  }

rgt.pad <- function(txt, n) {
  while (nchar(txt) < n) {
    txt <- paste(txt, "")
    }
  txt
  }
 


multree.to.Newick <- function(multree) {
root <- -1
for (n in 1:length(multree)) {
  if (multree[[n]]$anc < 0)
    {
    stopifnot(root < 0)
    root <- n
    }
  }
stopifnot(root > 0)
paste(mulsubtree.to.Newick(multree, root), ";", sep="")
}


mulsubtree.to.Newick <- function(multree, node) {
  lftnode <- multree[[node]]$lft
  rgtnode <- multree[[node]]$rgt
  if (lftnode > 0) {
    lftnewick <- mulsubtree.to.Newick(multree, lftnode)
    rgtnewick <- mulsubtree.to.Newick(multree, rgtnode)
    lftbtime <- multree[[node]]$nheight - multree[[lftnode]]$nheight
    rgtbtime <- multree[[node]]$nheight - multree[[rgtnode]]$nheight
    newick <- paste("(", lftnewick, ":", toString(lftbtime), ",",
                         rgtnewick, ":", toString(rgtbtime), ")", sep="")
    } else {
    newick <- multree[[node]]$clade
    }
  newick
  }



 
mnodes2mulsubtree <- function(multree, mnodes, n) {
  mnode <- mnodes[[n]]
  if (mnode$nheight == 0) {
    # tip
    newn <- mulnode.from.mnode(mnode) 
    multree <- c(multree, list(newn))
    } else {
    newn <- mulnode.from.mnode(mnode)
    sc <- splitclade(mnode$clade)
    
    hlft <- mnode.of.clade(mnodes, sc$lftclade)
    multree <- mnodes2mulsubtree(multree, mnodes, hlft)
    lft <- length(multree)
    
    hrgt <- mnode.of.clade(mnodes, sc$rgtclade)
    multree <- mnodes2mulsubtree(multree, mnodes, hrgt)
    rgt <- length(multree)
    
    multree <- c(multree, list(newn))
    here <- length(multree)
    
    multree[[lft]]$anc <- here
    multree[[rgt]]$anc <- here
    multree[[here]]$lft <- lft   
    multree[[here]]$rgt <- rgt  
    }
  multree
  } 
  
  

  
  
mulnode.from.mnode <- function(mnode) {
  clade <- mnode$clade
  list(clade=clade, anc=-1, lft=-1, rgt=-1, 
       nheight=mnode$nheight, hybheight=mnode$hybheight, 
       tippop=mnode$tippop, rootpop=mnode$rootpop, hybpop=mnode$hybpop,
       root=mnode$root, nlins=mnode$indivs)
}


       


dud.mulnode <- function() {
list(clade="", anc=-1, lft=-1, rgt=-1, root=FALSE,
       height=0, hybheight=-1, nlins=-1, 
       tippop=-1, hybpop=-1, rootpop=-1)
}


splitclade <- function(clade) {
  x <- strsplit(clade, split="")[[1]]
  stopifnot(x[1]=="(")
  stopifnot(x[length(x)]==")")
  level <- 0
  j <- -1
  for (i in 1:length(x)) {
    if (x[i] == "(") { level <- level + 1 }
    if (x[i] == ")") { level <- level - 1 }
    if (x[i] == ","  &&  level==1) {
      stopifnot(j==-1)
      j <- i
      }
    }
  stopifnot(j>0)
  lftclade <- paste(x[2:(j-1)], collapse="")
  rgtclade <- paste(x[(j+1):(length(x)-1)], collapse="")
  list(lftclade=lftclade, rgtclade=rgtclade) 
  } 


mnode.of.clade <- function(mnodes, clade) {
  j <- -1
  for (i in 1:length(mnodes)) {
    if (mnodes[[i]]$clade == clade) {
      stopifnot(j==-1)
      j <- i
      }
    }
  stopifnot(j>0)
  j
  }		
		
		
mulnode.of.clade <- function(multree, clade) {
  j <- -1
  for (i in 1:length(multree)) {
    if (multree[[i]]$clade == clade) {
      stopifnot(j==-1)
      j <- i
      }
    }
  cat("multree", clade, j, "\n")
  stopifnot(j>0)
  j
  }
