

setwd("C:/Users/Graham/AAA/Programming/Goteborg/AlloppRcode-nhybs")
source("AlloppDT_1readconfig.r")
source("Analysis_rfd_nex2treestring.r")
source("Analysis_rfd_nodetable2trlb.r")
source("Analysis_rfd_calc.r")



glue <- function(...) {
  paste(..., sep="")
}




rfd.onescenario <- function(dpath, Gs, Ns, Ts) {
  nG <- length(Gs)
  nN <- length(Ns)
  nT <- length(Ts)  
  rfd.results <- array(rep(-1,nG*nN*nT), dim=c(nG,nN,nT))
  rfdmiss.results <- array(rep(-1,nG*nN*nT), dim=c(nG,nN,nT))
  rfdtop.results <- array(rep(-1,nG*nN*nT), dim=c(nG,nN,nT))
  
  config <- read.config(dpath)  
  for (i in 1:length(config$configG)) {
    Gi <- which(Gs == config$configG[i])
    Ni <- which(Ns == config$configN[i])
    Ti <- which(Ts == config$configT[i])
    stopifnot(length(Gi)==1)
    stopifnot(length(Ni)==1)
    stopifnot(length(Ti)==1)
  
    trueMtree.fpath <- fpath.multree(config, i)
    trueMtree.trlbi <- nodetable.to.trlbi(trueMtree.fpath)
    trueMtree.trlbi <- remove.seqchars(trueMtree.trlbi, "A", "B")
    trueMtree.tetpairs <- find.tet.pairs(trueMtree.trlbi)
    trueMtree.trlbi <- add.seqchars(trueMtree.trlbi, trueMtree.tetpairs, "A", "B")
    trueMtree.clades <- trlbi.to.clades(trueMtree.trlbi)
    
    nreps <- config$configR[i]
    rfds <- rep(0,nreps)
    rfdmisses <- rep(0,nreps)
    rfdtops <- rep(0,nreps)
    for (r in 1:nreps) {
      concensusMtree.fpath <- fpath.mccmultree(config, i, r)
      concensusMtree <- tree.string.from.nexus(concensusMtree.fpath)               
      concensusMtree.trlbi.tetpairs <- newick.string.to.trlbi.and.tetpairs(concensusMtree, "0", "1")
      concensusMtree.trlbi <- concensusMtree.trlbi.tetpairs$trlbi
      concensusMtree.tetpairs <- concensusMtree.trlbi.tetpairs$tetpairs
      rfd <- multree.rfd(trueMtree.clades, concensusMtree.trlbi, concensusMtree.tetpairs)
      rfds[r] <- rfd$rfd
      rfdmisses[r] <- rfd$rfdmiss
      rfdtops[r] <- rfd$rfdtop
      }
    rfd.results[Gi,Ni,Ti] <-  mean(rfds)
    rfdmiss.results[Gi,Ni,Ti] <-  mean(rfdmisses)
    cat("G =", config$configG[i], "N =", config$configN[i], "T =", config$configT[i],
           "mean(rfd) =", mean(rfds), "mean(missrfd) =", mean(rfdmisses), " (")
    for (r in 1:nreps) {
      cat(rfdtops[r], " ")
      }
    cat(")\n")
    }
  list(rfd=rfd.results, rfdmiss=rfdmiss.results)
 }
 
 
 
plot.diagram <- function(w, h)
{
par(mar=c(0,0,0,0))
plot(NULL, xlim=c(0,w), ylim=c(0,h), axes=FALSE, ylab="", xlab="")
}



plot.rectangle <- function(v1,v2,...)
{
polygon(c(v1[1],v1[1],v2[1],v2[1]), c(v1[2],v2[2],v2[2],v1[2]), ...)
}


# This for main D,E,F scenarios
plot.data.DEF <- function(D.res, E.res, F.res, wid, hgt, brdx, brdy) {
  for (g in 1:3) {
    G <- Gs[g]
    GNox <- (g-1)*wid+brdx
    text(GNox+12, 2, paste("G=", G, sep=""), adj=c(0,0))
    for (n in 1:3) {
      N <- Ns[n]
      GNoy <- (3-n)*hgt+brdy
      text(2, GNoy+14, paste("N=", N, sep=""), adj=c(0,0), srt=90)
      GNDoy <- GNoy + 26
      for (t in 1:5) {
        TT <- Ts[t] 
        plot.rectangle(c(GNox, GNDoy+(t-1)*2), c(GNox+250*D.res$rfd[g,n,t], GNDoy+t*2), border=NA, col="gray")
        plot.rectangle(c(GNox, GNDoy+(t-1)*2), c(GNox+250*D.res$rfdmiss[g,n,t], GNDoy+t*2), border=NA, col="black")
        if (D.res$rfdmiss[g,n,t]==0) {
          plot.rectangle(c(GNox+16, GNDoy+(t-1)*2+0.5), c(GNox+18, GNDoy+t*2-0.5), border="black", col="white")
        }
      }
      text(GNox+20, GNDoy+6, paste("D"), adj=c(0,0.5))
      
      GNEoy <- GNoy + 14
      for (t in 1:5) {
        TT <- Ts[t]
        plot.rectangle(c(GNox, GNEoy+(t-1)*2), c(GNox+250*E.res$rfd[g,n,t], GNEoy+t*2), border=NA, col="gray")
        plot.rectangle(c(GNox, GNEoy+(t-1)*2), c(GNox+250*E.res$rfdmiss[g,n,t], GNEoy+t*2), border=NA, col="black")
        if (E.res$rfdmiss[g,n,t]==0) {
          plot.rectangle(c(GNox+16, GNEoy+(t-1)*2+0.5), c(GNox+18, GNEoy+t*2-0.5), border="black", col="white")
        }
      }
      text(GNox+20, GNEoy+6, paste("E"), adj=c(0,0.5))
      
      GNFoy <- GNoy + 2
      for (t in 1:5) {
        TT <- Ts[t]
        plot.rectangle(c(GNox, GNFoy+(t-1)*2), c(GNox+250*F.res$rfd[g,n,t], GNFoy+t*2), border=NA, col="gray")
        plot.rectangle(c(GNox, GNFoy+(t-1)*2), c(GNox+250*F.res$rfdmiss[g,n,t], GNFoy+t*2), border=NA, col="black")
        if (F.res$rfdmiss[g,n,t]==0) {
          plot.rectangle(c(GNox+16, GNFoy+(t-1)*2+0.5), c(GNox+18, GNFoy+t*2-0.5), border="black", col="white")
        }
      }
      text(GNox+20, GNFoy+6, paste("F"), adj=c(0,0.5))
      plot.rectangle(c(GNox,GNoy), c(GNox+wid,GNoy+hgt))
    }
  }
}



# This for J scenario
plot.data.J <- function(J.res, wid, hgt, brdx, brdy) {
  for (g in 1:1) {
    G <- Gs[g]
    GNox <- (g-1)*wid+brdx
    text(GNox+12, 2, paste("G=", G, sep=""), adj=c(0,0))
    for (n in 1:1) {
      N <- Ns[n]
      GNoy <- (1-n)*hgt+brdy
      text(2, GNoy+14, paste("N=", N, sep=""), adj=c(0,0), srt=90)
      GNJoy <- GNoy + 26
      for (t in 1:4) {
        TT <- Ts[t] 
        plot.rectangle(c(GNox, GNJoy+(t-1)*2), c(GNox+250*J.res$rfd[g,n,t], GNJoy+t*2), border=NA, col="gray")
        plot.rectangle(c(GNox, GNJoy+(t-1)*2), c(GNox+250*J.res$rfdmiss[g,n,t], GNJoy+t*2), border=NA, col="black")
        if (J.res$rfdmiss[g,n,t]==0) {
          plot.rectangle(c(GNox+16, GNJoy+(t-1)*2+0.5), c(GNox+18, GNJoy+t*2-0.5), border="black", col="white")
        }
      }
      text(GNox+20, GNJoy+6, paste("J"), adj=c(0,0.5))
      plot.rectangle(c(GNox,GNoy), c(GNox+wid,GNoy+hgt))
    }
  }
}





###########################################################################
# This for main D,E,F scenarios
#
#Gs <- c(1, 3, 9)
#Ns <- c(1, 3, 9)
#Ts <- c(5e-9, 1e-8, 2e-8, 4e-8, 8e-8)
#
#basedpath <- "C:/Users/Graham/AAA/Programming/GoteborgSim/2013-05-02-merged/"
#
#D.res <- rfd.onescenario(glue(basedpath, "D"), Gs, Ns, Ts)
#E.res <- rfd.onescenario(glue(basedpath, "E"), Gs, Ns, Ts)
#F.res <- rfd.onescenario(glue(basedpath, "F"), Gs, Ns, Ts)
#
#wid <- 35
#hgt <- 38
#brdx <- 4
#brdy <- 6
#plot.diagram(w=3*wid+brdx, h=3*hgt+brdy)
#plot.data.DEF(D.res, E.res, F.res, wid, hgt, brdx, brdy)
#
#
#postscript(file = "C:/Users/Graham/AAA/Docs/PCTeX/GoteborgDT/Article/rfdrfdmiss.eps",
#           width=3, height=5, pointsize=10, horizontal=FALSE,
#           paper="special")
#
#plot.diagram(w=3*wid+brdx, h=3*hgt+brdy)
#plot.data.DEF(D.res, E.res, F.res, wid, hgt, brdx, brdy)
#
# dev.off() 

#############################################################################



# This for scenario J with 6dips 7tets.
Gs <- c(3)
Ns <- c(1)
Ts <- c(2e-8, 4e-8, 8e-8, 16e-8)

basedpath <- "C:/Users/Graham/AAA/Programming/GoteborgSim/2012-10-31/"

J.res <- rfd.onescenario(glue(basedpath, "J"), Gs, Ns, Ts)

 

wid <- 35
hgt <- 38
brdx <- 4
brdy <- 6
plot.diagram(w=3*wid+brdx, h=hgt+brdy)
plot.data.J(J.res, wid, hgt, brdx, brdy)


postscript(file = "C:/Users/Graham/AAA/Docs/PCTeX/GoteborgDT/Article/6d7tresults.eps",
           width=3, height=2, pointsize=10, horizontal=FALSE,
           paper="special")
plot.diagram(w=3*wid+brdx, h=hgt+brdy)
plot.data.J(J.res, wid, hgt, brdx, brdy)
dev.off() 
























               

#G = 1 N = 1 T = 5e-09 mean(rfd) = 0.03201821 mean(missrfd) = 0.001416359  (0  0  0  0  0  0  0.01416359  0  0  0  )
#G = 1 N = 1 T = 1e-08 mean(rfd) = 0.03504374 mean(missrfd) = 0.008938822  (0  0.02671809  0  0.02493078  0.01708077  0  0  0.007652231  0.01300634  0  )
#G = 1 N = 1 T = 2e-08 mean(rfd) = 0.050303 mean(missrfd) = 0.01061032  (0.006452099  0.02019011  0  0.006468689  0.01144145  0.02055426  0.005752569  0.00322788  0.02351848  0.00849765  )
#G = 1 N = 1 T = 4e-08 mean(rfd) = 0.07840541 mean(missrfd) = 0.0346577  (0.0195304  0.01745617  0.02645087  0.03937595  0.007235289  0.08357009  0.03086028  0.08585416  0.01326248  0.02298133  )
#G = 1 N = 1 T = 8e-08 mean(rfd) = 0.1299594 mean(missrfd) = 0.06290224  (0.04813741  0.1813278  0.08736265  0.02314476  0.003795934  0.08648788  0.04437726  0.09199615  0.0536769  0.008715638  )

#G = 1 N = 3 T = 5e-09 mean(rfd) = 0.03019768 mean(missrfd) = 0.005666841  (0  0.003142171  0.01733611  0.009055776  0.01105347  0.005119785  0.003867341  0  0  0.007093749  )
#G = 1 N = 3 T = 1e-08 mean(rfd) = 0.03890825 mean(missrfd) = 0.007302546  (0.008376075  0.005322211  0.02944358  0  0.009596023  0.003584563  0.006105093  0.006179324  0  0.004418589  )
#G = 1 N = 3 T = 2e-08 mean(rfd) = 0.03317436 mean(missrfd) = 0.005125723  (0.0041659  0.01999377  0.007676492  0.003607655  0  0  0.003586666  0.007664527  0  0.004562212  )
#G = 1 N = 3 T = 4e-08 mean(rfd) = 0.038329 mean(missrfd) = 0.0115598  (0.003072093  0  0  0.01382662  0  0.02509667  0.02847162  0.003087452  0.04204353  0  )
#G = 1 N = 3 T = 8e-08 mean(rfd) = 0.03376064 mean(missrfd) = 0.01323145  (0.004373288  0.007419053  0.0193556  0.004229316  0.01775231  0  0  0.03899163  0.007224526  0.03296878  )

#G = 1 N = 9 T = 5e-09 mean(rfd) = 0.02533067 mean(missrfd) = 0.003341435  (0.003510222  0  0.0110746  0  0.01123076  0.003785675  0.003813088  0  0  0  )
#G = 1 N = 9 T = 1e-08 mean(rfd) = 0.0309488 mean(missrfd) = 0.003906902  (0  0.00304358  0  0  0  0  0.01383364  0.01116012  0.01103168  0  )
#G = 1 N = 9 T = 2e-08 mean(rfd) = 0.03000804 mean(missrfd) = 0.004177336  (0  0  0.006132103  0.0115947  0  0.00401469  0  0.008794494  0.003640946  0.007596435  )
#G = 1 N = 9 T = 4e-08 mean(rfd) = 0.02607417 mean(missrfd) = 0.005036134  (0.005201402  0  0.01261886  0.01551722  0.005215389  0.004797976  0  0.00304653  0  0.003963963  )
#G = 1 N = 9 T = 8e-08 mean(rfd) = 0.02764776 mean(missrfd) = 0.00507315  (0  0  0  0.02994322  0  0.02078828  0  0  0  0  )

#G = 3 N = 1 T = 5e-09 mean(rfd) = 0.02359933 mean(missrfd) = 0.00102866  (0.003066611  0  0  0  0  0  0.004047843  0  0  0.003172151  )
#G = 3 N = 1 T = 1e-08 mean(rfd) = 0.01875547 mean(missrfd) = 0.0003678188  (0  0  0  0.003678188  0  0  0  0  0  0  )
#G = 3 N = 1 T = 2e-08 mean(rfd) = 0.03110904 mean(missrfd) = 0.004883793  (0.005294947  0.004219799  0  0  0.01072948  0  0.004841296  0.01192583  0  0.01182658  )
#G = 3 N = 1 T = 4e-08 mean(rfd) = 0.03442197 mean(missrfd) = 0.007664185  (0.01070287  0.005661542  0.006925468  0.003435238  0.004258874  0  0.00421439  0.01277833  0.01107903  0.0175861  )
#G = 3 N = 1 T = 8e-08 mean(rfd) = 0.04249016 mean(missrfd) = 0.009738065  (0.02528986  0.01225912  0.004044843  0.01671267  0.00654204  0  0  0.01271105  0.007476211  0.01234486  )

#G = 3 N = 3 T = 5e-09 mean(rfd) = 0.02492538 mean(missrfd) = 0.001788339  (0  0.003013635  0  0  0  0  0.005613322  0  0.00925643  0  )
#G = 3 N = 3 T = 1e-08 mean(rfd) = 0.01865811 mean(missrfd) = 0.001154536  (0  0.004045453  0.003904674  0  0  0  0  0.003595235  0  0  )
#G = 3 N = 3 T = 2e-08 mean(rfd) = 0.02547324 mean(missrfd) = 0.001563327  (0  0  0.003975408  0  0  0  0  0.008403379  0  0.003254486  )
#G = 3 N = 3 T = 4e-08 mean(rfd) = 0.02027648 mean(missrfd) = 0.001586613  (0.003642522  0.00342335  0  0.003073243  0  0  0  0.005727019  0  0  )
#G = 3 N = 3 T = 8e-08 mean(rfd) = 0.02791683 mean(missrfd) = 0.005120173  (0  0  0.004135258  0.00414406  0  0  0.01871048  0  0.02421193  0  )

#G = 3 N = 9 T = 5e-09 mean(rfd) = 0.01667009 mean(missrfd) = 0.0003039505  (0  0  0  0  0  0  0.003039505  0  0  0  )
#G = 3 N = 9 T = 1e-08 mean(rfd) = 0.01641893 mean(missrfd) = 0.0003320704  (0  0.003320704  0  0  0  0  0  0  0  0  )
#G = 3 N = 9 T = 2e-08 mean(rfd) = 0.02160792 mean(missrfd) = 0.002347426  (0  0  0  0  0  0.009150022  0  0.008367751  0  0.005956485  )
#G = 3 N = 9 T = 4e-08 mean(rfd) = 0.02169099 mean(missrfd) = 0.005404814  (0.008242319  0.0092791  0  0.008905586  0.01019621  0.0143831  0  0.003041834  0  0  )
#G = 3 N = 9 T = 8e-08 mean(rfd) = 0.01795222 mean(missrfd) = 0.005321741  (0.0031703  0.003210687  0.009621065  0.008302821  0.008241048  0.004690196  0.00385951  0  0.003041969  0.009079812  )

#G = 9 N = 1 T = 5e-09 mean(rfd) = 0.01453874 mean(missrfd) = 0  (0  0  0  0  0  0  0  0  0  0  )
#G = 9 N = 1 T = 1e-08 mean(rfd) = 0.01745485 mean(missrfd) = 0.0003991002  (0  0  0  0  0  0  0.003991002  0  0  0  )
#G = 9 N = 1 T = 2e-08 mean(rfd) = 0.02287318 mean(missrfd) = 0.00115527  (0  0.003121478  0  0  0.004676294  0  0.003754928  0  0  0  )
#G = 9 N = 1 T = 4e-08 mean(rfd) = 0.02572915 mean(missrfd) = 0.002104409  (0  0.00406245  0.007960467  0  0  0.005861908  0.003159264  0  0  0  )
#G = 9 N = 1 T = 8e-08 mean(rfd) = 0.03099478 mean(missrfd) = 0.007683736  (0.007332515  0  0.004029692  0.004426133  0.00763355  0.009988944  0.00837224  0.006552768  0  0.02850152  )

#G = 9 N = 3 T = 5e-09 mean(rfd) = 0.01546301 mean(missrfd) = 0  (0  0  0  0  0  0  0  0  0  0  )
#G = 9 N = 3 T = 1e-08 mean(rfd) = 0.01545282 mean(missrfd) = 0.0003425208  (0  0  0  0  0  0  0  0  0  0.003425208  )
#G = 9 N = 3 T = 2e-08 mean(rfd) = 0.01705197 mean(missrfd) = 0  (0  0  0  0  0  0  0  0  0  0  )
#G = 9 N = 3 T = 4e-08 mean(rfd) = 0.01540486 mean(missrfd) = 0.0005764444  (0.005764444  0  0  0  0  0  0  0  0  0  )
#G = 9 N = 3 T = 8e-08 mean(rfd) = 0.01366836 mean(missrfd) = 0.0009435172  (0  0  0  0  0  0  0  0.004138934  0.005296238  0  )

#G = 9 N = 9 T = 5e-09 mean(rfd) = 0.01558866 mean(missrfd) = 0  (0  0  0  0  0  0  0  0  0  0  )
#G = 9 N = 9 T = 1e-08 mean(rfd) = 0.01210831 mean(missrfd) = 0  (0  0  0  0  0  0  0  0  0  0  )
#G = 9 N = 9 T = 2e-08 mean(rfd) = 0.02131074 mean(missrfd) = 0.005696577  (0  0  0  0.008205502  0  0.009428932  0.01019052  0.02914082  0  0  )
#G = 9 N = 9 T = 4e-08 mean(rfd) = 0.02304752 mean(missrfd) = 0.008656847  (0.02013537  0.00333554  0.003524575  0  0.009391975  0.01055129  0.003872438  0.01281408  0  0.02294321  )
#G = 9 N = 9 T = 8e-08 mean(rfd) = 0.02573242 mean(missrfd) = 0.01355863  (0.007238753  0.006521983  0.01591906  0.00926037  0.01688138  0.01739269  0.01298611  0.01697548  0.01762271  0.0147878  )
#