

# converts a file containing a MUL-tree in my own 
# format as a node table, like this:

# idx   clade                   anc  l  r      hgt   hybhgt nlin   tippop   hybpop  prevpop 
#  1 aA                           7 -1 -1        0       -1    9    2e+05       -1    2e+05 
#  2 zA                           4 -1 -1        0       -1    9    2e+05       -1    2e+05 
#  3 yA                           4 -1 -1        0       -1    9    2e+05       -1    2e+05 
#  4 (zA,yA)                      6  2  3    0.003       -1   -1       -1       -1    2e+05 
# ...

# into a "trlb", a simpler representation, like

# tipnames "aA" "zA" "yA" ""   "xA" ""   ""   "bA" "zB" "yB" ""   "xB" ""   ""   ""  
# lfts -1 -1 -1  2 -1  4  1 -1 -1 -1  9 -1 11  8  7
# rgts  -1 -1 -1  3 -1  5  6 -1 -1 -1 10 -1 12 13 14
# brlens  0.009 0.003 0.003 0.003 0.006 0.003 0.003 0.009 0.003 0.003 0.003 0.006 0.003 0.003 0.000

# where the brlens are branch lengths leading to clades.



nodetable.to.trlbi <- function(fpath) {
x <- read.table(fpath, header = TRUE, as.is=TRUE)
clades <- x[,"clade"]
nnodes <- nrow(x)
internalclades <- grep("[(]", x[,"clade"])
clades[internalclades] <- ""
clades
brlens <- rep(0, nnodes)
for (i in 1:(nnodes-1)) {
  brlens[i] <- x[x[i,"anc"],"hgt"] - x[i,"hgt"]
  }
list(tipnames=clades, lfts=x[,"l"], rgts=x[,"r"], brlens=brlens, nextni=nnodes+1)
}



